============
Installation
============

At the command line::

    $ easy_install ghubtrending

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv ghubtrending
    $ pip install ghubtrending
